<?php

namespace Litecms\Memo\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Memo\Models\Memo;

class MemoPolicy
{

    use MemoAction;
    use MemoReport;
    use MemoWorkflow;

    /**
     * Determine if the given user can view the memo.
     *
     * @param Authenticatable $user
     * @param Memo $memo
     *
     * @return bool
     */
    public function view(Authenticatable $user, Memo $memo)
    {
        if ($authUser->canDo('memo.memo.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $memo->is_owner;
    }

    /**
     * Determine if the given user can create a memo.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('memo.memo.create');
    }

    /**
     * Determine if the given user can update the given memo.
     *
     * @param Authenticatable $user
     * @param Memo $memo
     *
     * @return bool
     */
    public function update(Authenticatable $user, Memo $memo)
    {
        if ($user->canDo('memo.memo.edit') && $user->isAdmin()) {
            return true;
        }

        return $memo->is_owner;
    }

    /**
     * Determine if the given user can delete the given memo.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Memo $memo)
    {
        return $memo->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
